<?php

/*
Widget Name: APT accordion menu
Description: Show one of your created menus as a beautyful accordion menu.
Author: Me
Author URI: https://github.com/aptarmy
Widget URI: https://aptarmy.github.io/apt-news.io/hello-world-widget-docs,
Video URI: https://aptarmy.github.io/apt-news.io/hello-world-widget-video
*/

// this class will be used to register a widget
// siteorigin_wiget class was extended from WP_widget class
// so we can use constructor available in WP_widge class
class APT_Accordion_Menu extends APT_Widget_Menu {
	
	function __construct() {
		//Here you can do any preparation required before calling the parent constructor, such as including additional files or initializing variables.
		
		//Call the parent constructor with the required arguments.
		parent::__construct(
			// The unique id for your widget.
			'apt_accordion_menu',

			// The name of the widget for display purposes.
			__('APT accordion menu widget', 'apt-news'),

			// The $widget_options array, which is passed through to WP_Widget.
			// It has a couple of extras like the optional help URL, which should link to your sites help or support page.
			array(
				'description' => __('This widget will use one of your existing menus on WordPress and show it as a beaautyful accordion menu.', 'apt-news'),
				'help'        => 'https://aptarmy.github.io/apt-news.io/hello-world-widget-docs',
				'panels_groups' => array('apt_widgets'),
			),

			//The $control_options array, which is passed through to WP_Widget
			array(
			),

			//The $form_options array, which describes the form fields used to configure SiteOrigin widgets. We'll explain these in more detail later.
			array(
				
				// Select menu
				'menu' => array(
					'type' => 'select',
					'label' => __('Select which menu will be shown as accordion menu.', 'apt-news'),
					'default' => 'not_selected',
					'options' => $this->get_all_menus()
				),
				
				// Background
				// Outer
				'background_section' => array(
					'type' => 'section',
					'label' => __( 'Customize background of the menu' , 'apt-news' ),
					'hide' => true,
					'fields' => array(
						'outer_color' => array(
							'type' => 'color',
							'label' => __('Outer background color', 'apt-news'),
							'default' => '#323232',
						),
						'outer_image' => array(
							'type' => 'media',
							'library' => 'image',
							'label' => __('Outer background image', 'apt-news'),
							'default' => '0',
						),
						// Background
						// Inner
						'inner_color' => array(
							'type' => 'color',
							'label' => __('Inner background color', 'apt-news'),
							'default' => '#1a1a1a',
						),
						'inner_image' => array(
							'type' => 'media',
							'library' => 'image',
							'label' => __('Inner background image', 'apt-news'),
							'default' => '0',
						),
						// submenu item
						'subitem' => array(
							'type' => 'color',
							'label' => __('Submenu background color', 'apt-news'),
							'default' => '#0a0a0a',
						),
					),
				),
				// Menu items
				// level 1
				'menu_level_1_section' => array(
					'type' => 'section',
					'label' => __( 'Customize menu item in level 1' , 'apt-news' ),
					'hide' => true,
					'fields' => array(
						'icon' => array(
							'type' => 'icon',
							'label' => __('Icon', 'apt-news'),
							'default' => 'fontawesome-cog',
						),
						'icon_color' => array(
							'type' => 'color',
							'label' => __('Icon color', 'apt-news'),
							'default' => '#ffa500',
						),
						'text_color' => array(
							'type' => 'color',
							'label' => __('Text color', 'apt-news'),
							'default' => '#c8c8b4',
						),
					),
				),

				// Menu items
				// level 2
				'menu_level_2_section' => array(
					'type' => 'section',
					'label' => __( 'Customize menu item in level 2' , 'apt-news' ),
					'hide' => true,
					'fields' => array(
						'icon' => array(
							'type' => 'icon',
							'label' => __('Icon', 'apt-news'),
							'default' => 'fontawesome-microphone',
						),
						'icon_color' => array(
							'type' => 'color',
							'label' => __('Icon color', 'apt-news'),
							'default' => '#aaaab4',
						),
						'text_color' => array(
							'type' => 'color',
							'label' => __('Text color', 'apt-news'),
							'default' => '#14b464',
						),
						'text_hover_color' => array(
							'type' => 'color',
							'label' => __('Text color when hover', 'apt-news'),
							'default' => '#aae600'
						),
					),
				),
				$this->get_float_id() => $this->get_float_options(),
				$this->get_media_query_id() => $this->get_media_query_options(),
			),

			//The $base_folder path string.
			plugin_dir_path(__FILE__)
		);
	}
		
	/* Get template file */
    function get_template_name($instance) {
		return 'template';
    }

	/* Get less file */
    function get_style_name($instance) {
        return 'style';
    }
	
	/* set less variable */
	function get_less_variables($instance){
		return array(
			'outer_background_color' => $instance['background_section']['outer_color'],
			'outer_background_image' => ($instance['background_section']['outer_image'] == 0) ? 'none' : 'url(' . wp_get_attachment_image_src($instance['background_section']['outer_image'])[0] . ')',
			'inner_background_color' => $instance['background_section']['inner_color'],
			'inner_background_image' => ($instance['background_section']['inner_image'] == 0) ? 'none' : 'url(' . wp_get_attachment_image_src($instance['background_section']['inner_image'])[0] . ')',
			'subitem_background_color' => $instance['background_section']['subitem'],
			'menu_item_1_color' => $instance['menu_level_1_section']['text_color'],
			'menu_item_2_color' => $instance['menu_level_2_section']['text_color'],
			'menu_item_2_hover_color' => $instance['menu_level_2_section']['text_hover_color'],
		);
	}
}
// siteorigin_widget_register($desired_widget_id, $path_to_widget, $class_used_to_create_widget)
siteorigin_widget_register('apt_accordion_menu', __FILE__, 'APT_Accordion_Menu');