<?php

/*
Widget Name: APT big post banner
Description: show a big post as a featured post banner.
Author: Me
Author URI: https://github.com/aptarmy
Widget URI: https://aptarmy.github.io/apt-news.io/hello-world-widget-docs,
Video URI: https://aptarmy.github.io/apt-news.io/hello-world-widget-video
*/

// this class will be used to register a widget
// siteorigin_wiget class was extended from WP_widget class
// so we can use constructor available in WP_widge class
class APT_Big_Post_Banner extends APT_Widget {
	
	public $plugin_url;
	
	function __construct() {
		//Here you can do any preparation required before calling the parent constructor, such as including additional files or initializing variables.
		$this->plugin_url = theme_dir_url(__FILE__);
		
		//Call the parent constructor with the required arguments.
		parent::__construct(
			// The unique id for your widget.
			'apt_big_post_banner',

			// The name of the widget for display purposes.
			__('APT big post banner', 'apt-news'),

			// The $widget_options array, which is passed through to WP_Widget.
			// It has a couple of extras like the optional help URL, which should link to your sites help or support page.
			array(
				'description' => __('Show your selected post as a post banner.', 'apt-news'),
				'help'        => 'https://aptarmy.github.io/apt-news.io/hello-world-widget-docs',
				'panels_groups' => array('apt_widgets'),
			),

			//The $control_options array, which is passed through to WP_Widget
			array(
			),

			//The $form_options array, which describes the form fields used to configure SiteOrigin widgets. We'll explain these in more detail later.
			array(
				'posts' => array(
					'type' => 'posts',
					'label' => __('Select what post should be displyed as a banner post.', 'apt-news'),
				),
				'img_height' => array(
					'type' => 'number',
					'label' => __('Image height in px unit', 'apt-news'),
					'default' => '442',
				),
				'post_title_section' => array(
					'type' => 'section',
					'label' => __( 'Customize post title' , 'apt-news' ),
					'hide' => true,
					'fields' => array(
						'icon' => array(
							'type' => 'icon',
							'label' => __('Icon', 'apt-news'),
						),
						'icon_color' => array(
							'type' => 'color',
							'label' => __('Icon color', 'apt-news'),
							'default' => '#ffa500',
						),
						'text_color' => array(
							'type' => 'color',
							'label' => __('Text color', 'apt-news'),
							'default' => '#001400',
						),
					),
				),
				$this->get_float_id() => $this->get_float_options(),
				$this->get_media_query_id() => $this->get_media_query_options(),
			),

			//The $base_folder path string.
			plugin_dir_path(__FILE__)
		);
	}

	/* Get template file */
    function get_template_name($instance) {
        return 'template';
    }

	/* Get less file */
    function get_style_name($instance) {
        return 'style';
    }
	
	/* set less variable */
	function get_less_variables($instance){
		return array(
			'post_title_text_color' => $instance['post_title_section']['text_color'],
			'img_height' => $instance['img_height'] . 'px',
		);
	}
}
// siteorigin_widget_register($desired_widget_id, $path_to_widget, $class_used_to_create_widget)
siteorigin_widget_register('apt_big_post_banner', __FILE__, 'APT_Big_Post_Banner');