<?php

/*
Widget Name: ATP post thumbnail
Description: Show post thumbnail 1 row multiple column.
Author: Me
Author URI: https://github.com/aptarmy
Widget URI: https://aptarmy.github.io/apt-news.io/hello-world-widget-docs,
Video URI: https://aptarmy.github.io/apt-news.io/hello-world-widget-video
*/

// this class will be used to register a widget
// siteorigin_wiget class was extended from WP_widget class
// so we can use constructor available in WP_widge class
class APT_Posts_Thumbnail extends APT_Widget {
	
	function __construct() {
		//Here you can do any preparation required before calling the parent constructor, such as including additional files or initializing variables.

		//Call the parent constructor with the required arguments.
		parent::__construct(
			// The unique id for your widget.
			'apt_post_thumbnail',

			// The name of the widget for display purposes.
			__('APT post thumbnail', 'apt-news'),

			// The $widget_options array, which is passed through to WP_Widget.
			// It has a couple of extras like the optional help URL, which should link to your sites help or support page.
			array(
				'description' => __('Show post thumbnail 1 row multiple column.', 'apt-news'),
				'help'        => 'https://aptarmy.github.io/apt-news.io/hello-world-widget-docs',
				'panels_groups' => array('apt_widgets'),
			),

			//The $control_options array, which is passed through to WP_Widget
			array(
			),

			//The $form_options array, which describes the form fields used to configure SiteOrigin widgets. We'll explain these in more detail later.
			array(
				'posts' => array(
					'type' => 'posts',
					'label' => __('Select post to show as post thumbnail', 'apt-news'),
				),
				'thumbnail_height' => array(
					'type' => 'number',
					'label' => __('Thumbnail height in px unit', 'apt-news'),
					'default' => '150',
				),
				'thumbnail_gutter' => array(
					'type' => 'number',
					'label' => __('Thumbnail gutter in px unit', 'apt-news'),
					'default' => '5',
				),
				$this->get_media_query_id() => $this->get_media_query_options(),
			),

			//The $base_folder path string.
			plugin_dir_path(__FILE__)
		);
	}

	/* Get template file */
    function get_template_name($instance) {
        return 'template';
    }

	/* Get less file */
    function get_style_name($instance) {
        return 'style';
    }
	
	/* set less variable */
	function get_less_variables($instance){
		return array(
			'thumbnail_height' => $instance['thumbnail_height'] . 'px',
			'thumbnail_gutter' => $instance['thumbnail_gutter'] . 'px',
		);
	}
}
// siteorigin_widget_register($desired_widget_id, $path_to_widget, $class_used_to_create_widget)
siteorigin_widget_register('apt_post_thumbnail', __FILE__, 'APT_Posts_Thumbnail');